@@ -17,6 +17,7 @@ def _get_kwargs(
     json_body: RunScriptByPathJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -34,6 +35,8 @@ def _get_kwargs(
 
     params["scheduled_in_secs"] = scheduled_in_secs
 
+    params["skip_preprocessor"] = skip_preprocessor
+
     params["parent_job"] = parent_job
 
     params["tag"] = tag
@@ -83,6 +86,7 @@ def sync_detailed(
     json_body: RunScriptByPathJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -96,6 +100,7 @@ def sync_detailed(
         path (str):
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
+        skip_preprocessor (Union[Unset, None, bool]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         cache_ttl (Union[Unset, None, str]):
@@ -117,6 +122,7 @@ def sync_detailed(
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
+        skip_preprocessor=skip_preprocessor,
         parent_job=parent_job,
         tag=tag,
         cache_ttl=cache_ttl,
@@ -139,6 +145,7 @@ async def asyncio_detailed(
     json_body: RunScriptByPathJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -152,6 +159,7 @@ async def asyncio_detailed(
         path (str):
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
+        skip_preprocessor (Union[Unset, None, bool]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         cache_ttl (Union[Unset, None, str]):
@@ -173,6 +181,7 @@ async def asyncio_detailed(
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
+        skip_preprocessor=skip_preprocessor,
         parent_job=parent_job,
         tag=tag,
         cache_ttl=cache_ttl,
