@@ -16,6 +16,7 @@ def _get_kwargs(
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -27,6 +28,8 @@ def _get_kwargs(
 
     params["tag"] = tag
 
+    params["cache_ttl"] = cache_ttl
+
     params["job_id"] = job_id
 
     params["include_header"] = include_header
@@ -74,6 +77,7 @@ def sync_detailed(
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -85,6 +89,7 @@ def sync_detailed(
         path (str):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        cache_ttl (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
@@ -104,6 +109,7 @@ def sync_detailed(
         json_body=json_body,
         parent_job=parent_job,
         tag=tag,
+        cache_ttl=cache_ttl,
         job_id=job_id,
         include_header=include_header,
         queue_limit=queue_limit,
@@ -124,6 +130,7 @@ async def asyncio_detailed(
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
@@ -135,6 +142,7 @@ async def asyncio_detailed(
         path (str):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        cache_ttl (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
@@ -154,6 +162,7 @@ async def asyncio_detailed(
         json_body=json_body,
         parent_job=parent_job,
         tag=tag,
+        cache_ttl=cache_ttl,
         job_id=job_id,
         include_header=include_header,
         queue_limit=queue_limit,
