@@ -15,12 +15,14 @@ class ExecuteComponentJsonBodyRawCode:
         content (str):
         language (str):
         path (Union[Unset, str]):
+        lock (Union[Unset, str]):
         cache_ttl (Union[Unset, int]):
     """
 
     content: str
     language: str
     path: Union[Unset, str] = UNSET
+    lock: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -28,6 +30,7 @@ class ExecuteComponentJsonBodyRawCode:
         content = self.content
         language = self.language
         path = self.path
+        lock = self.lock
         cache_ttl = self.cache_ttl
 
         field_dict: Dict[str, Any] = {}
@@ -40,6 +43,8 @@ class ExecuteComponentJsonBodyRawCode:
         )
         if path is not UNSET:
             field_dict["path"] = path
+        if lock is not UNSET:
+            field_dict["lock"] = lock
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
 
@@ -54,12 +59,15 @@ class ExecuteComponentJsonBodyRawCode:
 
         path = d.pop("path", UNSET)
 
+        lock = d.pop("lock", UNSET)
+
         cache_ttl = d.pop("cache_ttl", UNSET)
 
         execute_component_json_body_raw_code = cls(
             content=content,
             language=language,
             path=path,
+            lock=lock,
             cache_ttl=cache_ttl,
         )
 
