@@ -45,6 +45,8 @@ class NewScript:
         visible_to_runner_only (Union[Unset, bool]):
         no_main_func (Union[Unset, bool]):
         codebase (Union[Unset, str]):
+        has_preprocessor (Union[Unset, bool]):
+        on_behalf_of_email (Union[Unset, str]):
     """
 
     path: str
@@ -74,6 +76,8 @@ class NewScript:
     visible_to_runner_only: Union[Unset, bool] = UNSET
     no_main_func: Union[Unset, bool] = UNSET
     codebase: Union[Unset, str] = UNSET
+    has_preprocessor: Union[Unset, bool] = UNSET
+    on_behalf_of_email: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -114,6 +118,8 @@ class NewScript:
         visible_to_runner_only = self.visible_to_runner_only
         no_main_func = self.no_main_func
         codebase = self.codebase
+        has_preprocessor = self.has_preprocessor
+        on_behalf_of_email = self.on_behalf_of_email
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -170,6 +176,10 @@ class NewScript:
             field_dict["no_main_func"] = no_main_func
         if codebase is not UNSET:
             field_dict["codebase"] = codebase
+        if has_preprocessor is not UNSET:
+            field_dict["has_preprocessor"] = has_preprocessor
+        if on_behalf_of_email is not UNSET:
+            field_dict["on_behalf_of_email"] = on_behalf_of_email
 
         return field_dict
 
@@ -242,6 +252,10 @@ class NewScript:
 
         codebase = d.pop("codebase", UNSET)
 
+        has_preprocessor = d.pop("has_preprocessor", UNSET)
+
+        on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
+
         new_script = cls(
             path=path,
             summary=summary,
@@ -270,6 +284,8 @@ class NewScript:
             visible_to_runner_only=visible_to_runner_only,
             no_main_func=no_main_func,
             codebase=codebase,
+            has_preprocessor=has_preprocessor,
+            on_behalf_of_email=on_behalf_of_email,
         )
 
         new_script.additional_properties = d
