@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.queued_job_raw_flow_modules_item_mock import QueuedJobRawFlowModulesItemMock
     from ..models.queued_job_raw_flow_modules_item_retry import QueuedJobRawFlowModulesItemRetry
+    from ..models.queued_job_raw_flow_modules_item_skip_if import QueuedJobRawFlowModulesItemSkipIf
     from ..models.queued_job_raw_flow_modules_item_sleep_type_0 import QueuedJobRawFlowModulesItemSleepType0
     from ..models.queued_job_raw_flow_modules_item_sleep_type_1 import QueuedJobRawFlowModulesItemSleepType1
+    from ..models.queued_job_raw_flow_modules_item_stop_after_all_iters_if import (
+        QueuedJobRawFlowModulesItemStopAfterAllItersIf,
+    )
     from ..models.queued_job_raw_flow_modules_item_stop_after_if import QueuedJobRawFlowModulesItemStopAfterIf
     from ..models.queued_job_raw_flow_modules_item_suspend import QueuedJobRawFlowModulesItemSuspend
 
@@ -24,6 +28,8 @@ class QueuedJobRawFlowModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, QueuedJobRawFlowModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, QueuedJobRawFlowModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, QueuedJobRawFlowModulesItemSkipIf]):
         sleep (Union['QueuedJobRawFlowModulesItemSleepType0', 'QueuedJobRawFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class QueuedJobRawFlowModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "QueuedJobRawFlowModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "QueuedJobRawFlowModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "QueuedJobRawFlowModulesItemSkipIf"] = UNSET
     sleep: Union["QueuedJobRawFlowModulesItemSleepType0", "QueuedJobRawFlowModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class QueuedJobRawFlowModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class QueuedJobRawFlowModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class QueuedJobRawFlowModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.queued_job_raw_flow_modules_item_mock import QueuedJobRawFlowModulesItemMock
         from ..models.queued_job_raw_flow_modules_item_retry import QueuedJobRawFlowModulesItemRetry
+        from ..models.queued_job_raw_flow_modules_item_skip_if import QueuedJobRawFlowModulesItemSkipIf
         from ..models.queued_job_raw_flow_modules_item_sleep_type_0 import QueuedJobRawFlowModulesItemSleepType0
         from ..models.queued_job_raw_flow_modules_item_sleep_type_1 import QueuedJobRawFlowModulesItemSleepType1
+        from ..models.queued_job_raw_flow_modules_item_stop_after_all_iters_if import (
+            QueuedJobRawFlowModulesItemStopAfterAllItersIf,
+        )
         from ..models.queued_job_raw_flow_modules_item_stop_after_if import QueuedJobRawFlowModulesItemStopAfterIf
         from ..models.queued_job_raw_flow_modules_item_suspend import QueuedJobRawFlowModulesItemSuspend
 
@@ -146,6 +170,20 @@ class QueuedJobRawFlowModulesItem:
         else:
             stop_after_if = QueuedJobRawFlowModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, QueuedJobRawFlowModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = QueuedJobRawFlowModulesItemStopAfterAllItersIf.from_dict(_stop_after_all_iters_if)
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, QueuedJobRawFlowModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = QueuedJobRawFlowModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["QueuedJobRawFlowModulesItemSleepType0", "QueuedJobRawFlowModulesItemSleepType1", Unset]:
@@ -214,6 +252,8 @@ class QueuedJobRawFlowModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
