@@ -27,6 +27,8 @@ class RawScript:
         tag (Union[Unset, str]):
         concurrent_limit (Union[Unset, float]):
         concurrency_time_window_s (Union[Unset, float]):
+        custom_concurrency_key (Union[Unset, str]):
+        is_trigger (Union[Unset, bool]):
     """
 
     input_transforms: "RawScriptInputTransforms"
@@ -38,6 +40,8 @@ class RawScript:
     tag: Union[Unset, str] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_time_window_s: Union[Unset, float] = UNSET
+    custom_concurrency_key: Union[Unset, str] = UNSET
+    is_trigger: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -53,6 +57,8 @@ class RawScript:
         tag = self.tag
         concurrent_limit = self.concurrent_limit
         concurrency_time_window_s = self.concurrency_time_window_s
+        custom_concurrency_key = self.custom_concurrency_key
+        is_trigger = self.is_trigger
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -74,6 +80,10 @@ class RawScript:
             field_dict["concurrent_limit"] = concurrent_limit
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if custom_concurrency_key is not UNSET:
+            field_dict["custom_concurrency_key"] = custom_concurrency_key
+        if is_trigger is not UNSET:
+            field_dict["is_trigger"] = is_trigger
 
         return field_dict
 
@@ -100,6 +110,10 @@ class RawScript:
 
         concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
 
+        custom_concurrency_key = d.pop("custom_concurrency_key", UNSET)
+
+        is_trigger = d.pop("is_trigger", UNSET)
+
         raw_script = cls(
             input_transforms=input_transforms,
             content=content,
@@ -110,6 +124,8 @@ class RawScript:
             tag=tag,
             concurrent_limit=concurrent_limit,
             concurrency_time_window_s=concurrency_time_window_s,
+            custom_concurrency_key=custom_concurrency_key,
+            is_trigger=is_trigger,
         )
 
         raw_script.additional_properties = d
